Lua_ExpeditionBoxDetailsWindow = class("Lua_ExpeditionBoxDetailsWindow", Lua_Window);
function Lua_ExpeditionBoxDetailsWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ExpeditionBoxDetailsWindow";
	self.skinName = "ExpeditionBoxDetailsWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ExpeditionBoxDetailsWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 625, 700, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -43, 0);
	self.itemList:setListCell(Lua_ExpeditionBoxDetailsItem, 625, 180, 1);
	self.itemList:setCellSpacing(0, 5);

	self:addLuaEvent("EXPEDITION_STAR_REWARD", self, self.updateShowInfo);
	self:updateShowInfo();
end

function Lua_ExpeditionBoxDetailsWindow:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.itemArr ~= nil then
		self.itemArr:clear();
		self.itemArr = nil;
	end
	self:superCall("dispose");
end

function Lua_ExpeditionBoxDetailsWindow:updateShowInfo()
	local config = DataCenter.expeditionUtil:getStarInfo();
	if self.itemArr == nil then
		self.itemArr = Array();
		for i = 1, #config do
			self.itemArr:add(config[i])
		end
	end
	self.itemArr:sortf(self, self.onSortFun);
	self.itemList:setArrayData(self.itemArr);
end

function Lua_ExpeditionBoxDetailsWindow:onSortFun(a, b)
	local _a = DataCenter.expeditionData:getStarState(a.id);
	local _b = DataCenter.expeditionData:getStarState(b.id);
	if _a == _b then
		if a.id > b.id then
			return false;
		end
	else
		if _a == 2 and _b ~= 2 then
			return false;
		elseif _a ~= 1 and _b == 1 then
			return false;
		end
	end
	return true;
end




















Lua_ExpeditionBoxDetailsItem = class("Lua_ExpeditionBoxDetailsItem", Lua_ListCell);
function Lua_ExpeditionBoxDetailsItem:ctor(p)
	self:superCall("ctor", p, "ExpeditionBoxDetailsItem_skin");
end

function Lua_ExpeditionBoxDetailsItem:buildShowItem()
	self:superCall("buildShowItem");

	local itemW = Mathf.Ceil(124 * 0.9);
	local width = 4 * itemW + 3 * 10;
	self.itemList = Lua_DragList.new(self.content, width, 126, Lua_AxisDefine.Horizontal);
	self.itemList:setRectPivot(3);
	self.itemList:setLocation(-295, -17);
	self.itemList:setListCell(Lua_ExpeditionBoxDetailsItemIcon, itemW, 126, 1);
	self.itemList:setCellSpacing(10, 0);
	self:setSubList(self.itemList);

	self.btnReceive:addClickFuntion(self, self.onBtnReceiveClick);
end

function Lua_ExpeditionBoxDetailsItem:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionBoxDetailsItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.titleText.text = LanUtil.formateStr(330034, tostring(data.star_num));
	self.titleText:resetSize();
	self.starIcon:setLocation(self.titleText.posX + self.titleText.width + 15, 68, 0);
	if data.reward ~= nil then
		self.itemList.canDrag = #data.reward > 4;
	end
	self.itemList:setArrayData(data.reward);

	local starNum = DataCenter.expeditionData.star_num;
	self.state = DataCenter.expeditionData:getStarState(data.id);
	if self.state == 2 then
		self.btnReceive:setEnable(false);
		self.receiveIcon:setEnable(true);
		self.starNum.text = nil;
		self.starBar:setEnable(false);
		self:showRedDot(false);
	elseif self.state == 1 then
		self.btnReceive:setEnable(true);
		self.receiveIcon:setEnable(false);
		self.starNum.text = nil;
		self.starBar:setEnable(false);
		self:showRedDot(true);
	else
		self.btnReceive:setEnable(false);
		self.receiveIcon:setEnable(false);
		self.starNum.text = starNum.."/"..data.star_num;
		self.starBar:setEnable(true);
		self.starBar:setMaxValue(data.star_num);
		self.starBar:setValue(starNum);
		self:showRedDot(false);
	end
end

function Lua_ExpeditionBoxDetailsItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(280, 0, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_ExpeditionBoxDetailsItem:onBtnReceiveClick(go)
	if self.data == nil then
		return;
	end
	
	if self.state == 1 then
		Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sBoxReceive(self.data.id);
	end
end




















Lua_ExpeditionBoxDetailsItemIcon = class("Lua_ExpeditionBoxDetailsItemIcon", Lua_ItemIconCell);
function Lua_ExpeditionBoxDetailsItemIcon:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ExpeditionBoxDetailsItemIcon:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.9, 0.9, 0.9);
end

function Lua_ExpeditionBoxDetailsItemIcon:setData(data)
	self:superCall("setData",data);

	if DataCenter.backstageActData:getActivitiesOpenState(10009, 1001) then
		local mdata = DataCenter.moreDoubleData:getMoreDoubleVoById(1001);
		if mdata ~= nil then
			self.itemIcon:setDoubleIcon(mdata.times);
			self.itemIcon:showNum(self.data.count*mdata.times);
		end
	else
		self.itemIcon:setDoubleIcon(0);
	end
end