-- 制作UI时，台子面居中，方便设置、计算点击区域
Lua_ExpeditionSingleItem = class("Lua_ExpeditionSingleItem", Lua_DisplayObject);
function Lua_ExpeditionSingleItem:ctor(p)
	self:superCall("ctor", p, "ExpeditionSingleItem_skin");
end

function Lua_ExpeditionSingleItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_ExpeditionSingleItem:dispose()
	Lua_CommonUtil.removeTimer(self, self.onDelayEnable)
	Lua_CommonUtil.removeTimer(self, self.removeEff)
	if self.modelEffImg then
		self.modelEffImg:dispose();
		self.modelEffImg = nil;
	end
	if self.arrowEff then
		self.arrowEff:dispose();
		self.arrowEff = nil;
	end
	if self.boxEff then
		self.boxEff:dispose();
		self.boxEff = nil;
	end
	if self.boxEff2 then
		self.boxEff2:dispose();
		self.boxEff2 = nil;
	end
	if self.enterEff then
		self.enterEff:dispose();
		self.enterEff = nil;
	end
	self:removeEff()
	self.data = nil;
	self.index = nil;
	self.eventData = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionSingleItem:checkInBound(touchX, touchY)
	local posX = self.posX or 0
	local posY = self.posY or 0
	local scaleX = self.scaleX or 1
	local scaleY = self.scaleY or 1
	local minX = posX - self.w / 2 * scaleX
	local maxX = posX + self.w / 2 * scaleX
	local minY = posY - self.h / 2 * scaleY
	local maxY = posY + self.h / 2 * scaleY
	if touchX >= minX and touchX <= maxX and touchY >= minY and touchY <= maxY then
		return true
	end
	return false
end

function Lua_ExpeditionSingleItem:init()
	self:showBoxEff(nil)
	self:showIcon(nil);
	self:showModel(nil);
	self:showArrow(false);
	self:showStar(0);
end

function Lua_ExpeditionSingleItem:setData(data, index, value)
	self:init()

	self.data = data;
	self.index = index;
	self.checkEff = value;
	self.canClick = false; -- 是否可点击
	self.canOperate = false; -- 是否可操作
	
	local eventId = DataCenter.expeditionData:getLatticeEvent(data.id, index);
	self.eventData = DataCenter.expeditionUtil:getLatticeInfo(eventId);
	if self.eventData == nil then
		return;
	end

	local bPass, passEventId = DataCenter.expeditionData:getLatticeState(data.id, index);
	local cur_stage = DataCenter.expeditionData.cur_stage;
	local cur_location = DataCenter.expeditionData.cur_location;
	local cur_state = DataCenter.expeditionData.cur_state;
	local cur_difficulty = DataCenter.expeditionData.cur_difficulty;

	if data.stage > 7 then
		self.baseIcon:setEnable(false);
		self.path_1:setEnable(false);
		self.path_2:setEnable(false);
		if not bPass then
			local canClick, canOperate, iconName, modelName, starNum = self:getInfo(data, index, self.eventData);
			if canClick and data.stage == 10 then
				if self.enterEff == nil then
					self.enterEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_bjyz_csm_01", "ui_bjyz_csm_01", 0, 0)
				else
					self.enterEff:setEnable(true)
				end
			else
				if self.enterEff then
					self.enterEff:setEnable(false)
				end
			end

			self.canClick = canClick;
			self.canOperate = canOperate;
			self:showStar(starNum)
			if self.eventData.type == 7 then -- 全层奖励
				if cur_difficulty <= 0 then
					self:showIcon("ui_bjyz_icon_02")
				else
					self:showIcon("ui_bjyz_icon_03")
				end
				if canOperate == true then
					if cur_difficulty <= 0 then
						self:showBoxEff("ui_ty_dbx_0101_4")
					else
						self:showBoxEff("ui_ty_dbx_0101_5")
					end
				end
			else
				if not strIsNullOrEmpty(iconName) then
					self:showIcon(iconName)
					self:showModel(nil)
				elseif not strIsNullOrEmpty(modelName) then
					self:showIcon(nil)
					self:showModel(modelName)
				else
					self:showIcon(nil)
					self:showModel(nil)
				end
			end
		end
		return;
	end

	local value1 = false;
	local value2 = false;
	-- 已通关
	if bPass then
		if eventId == passEventId then
			if data.stage == cur_stage then
				if data.stage == 7 then
					value1 = (not (index == 1));
					value2 = (not (index == 2));
				elseif data.map == 3 then
					value1 = (not (index == 1));
					value2 = (not (index == 3));
				else
					value1 = true;
					value2 = true;
				end
			else
				local map, next_idx = DataCenter.expeditionData:getStageInfo(data.next_id);
				if cur_state == 1 and data.stage == cur_stage - 1 then
					value1, value2 = self:updatePath(data.map, index, map, cur_location);
				else
					value1, value2 = self:updatePath(data.map, index, map, next_idx);
				end
			end
		end
		self:setPathEnable(eventId == passEventId, value1, value2)

		self.baseIcon.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		self.path_1.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		self.path_2.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		self.icon.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		if self.modelEffImg then
			self.modelEffImg.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
		end
	else
		if data.stage == 7 then
			value1 = (not (index == 1));
			value2 = (not (index == 2));
		else
			if data.map == 3 then
				if data.stage == cur_stage and cur_state == 1 then
					value1 = (not (index == 1) and index == cur_location);
					value2 = (not (index == 3) and index == cur_location);
				else
					value1 = (not (index == 1));
					value2 = (not (index == 3));
				end
			else
				if data.stage == cur_stage and cur_state == 1 then
					value1 = (index == cur_location);
					value2 = (index == cur_location);
				else
					value1 = true;
					value2 = true;
				end
			end
		end
		self:setPathEnable(true, value1, value2)

		local canClick, canOperate, iconName, modelName, starNum = self:getInfo(data, index, self.eventData);
		self.canClick = canClick;
		self.canOperate = canOperate;
		if not strIsNullOrEmpty(iconName) then
			self:showIcon(iconName)
			self:showModel(nil)
		elseif not strIsNullOrEmpty(modelName) then
			self:showIcon(nil)
			self:showModel(modelName)
		else
			self:showIcon(nil)
			self:showModel(nil)
		end
		self:showStar(starNum)

		if self.canOperate then
			self.baseIcon.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
			self.icon.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
			if self.modelEffImg then
				self.modelEffImg.colorStr = Lua_ColorDefine.transColorStr("FFFFFF")
			end
		else
			self.baseIcon.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
			self.icon.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
			if self.modelEffImg then
				self.modelEffImg.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
			end
		end
		self.path_1.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
		self.path_2.colorStr = Lua_ColorDefine.transColorStr("C8C8C8")
	end
end

-- canClick, canOperate, icon_name, model_name, starNum
function Lua_ExpeditionSingleItem:getInfo(data, index, eventData)
	local cur_stage = DataCenter.expeditionData.cur_stage;
	local cur_location = DataCenter.expeditionData.cur_location;
	local cur_state = DataCenter.expeditionData.cur_state; -- 0：无操作 1：操作中
	if cur_state == 0 then
		if data.stage == cur_stage + 1 then
			local canOperate = false;
			local list = data.can_select_pos[cur_location];
			if list ~= nil then
				for i = 1, #list do
					if list[i] == index then
						canOperate = true;
					end
				end
			end
			self:showArrow(canOperate)
			return true, canOperate, eventData.icon_name, eventData.model_name, eventData.star
		elseif data.stage == cur_stage + 2 then
			if data.next_id ~= nil and data.next_id > 0 then -- 门要等全层奖励领取后才可显示
				return true, false, eventData.icon_name, eventData.model_name, eventData.star
			end
		else
			if eventData.show_model == 1 then
				return true, false, eventData.icon_name, eventData.model_name, eventData.star
			end
		end
	elseif cur_state == 1 then
		if data.stage == cur_stage then
			if index == cur_location then
				self:showArrow(true)
				if data.need_buff == 1 and DataCenter.expeditionData.buff_state == 1 then
					return true, true, "ui_bjyz_icon_00"..(eventData.star + 2), eventData.model_name, 0
				else
					return true, true, eventData.icon_name, eventData.model_name, eventData.star
				end
			else
				self.baseIcon:setEnable(false);
			end
		elseif data.stage == cur_stage + 1 then
			return true, false, eventData.icon_name, eventData.model_name, eventData.star
		else
			if eventData.show_model == 1 then
				return true, false, eventData.icon_name, eventData.model_name, eventData.star
			end
		end
	end
	return false, false, nil, nil, 0
end

function Lua_ExpeditionSingleItem:updatePath(curMap, curIdx, nextMap, nextIdx)
	-- print(self.data.id, curMap, curIdx, nextMap, nextIdx)
	if curMap == 3 then -- nextMap是2
		if curIdx == 1 then
			return false, nextIdx == 1;
		elseif curIdx == 2 then
			return nextIdx == 1, nextIdx == 2;
		else
			return nextIdx == 2, false;
		end
	elseif curMap == 2 then
		if nextMap == 1 then
			if curIdx == 1 then
				return false, true;
			else
				return true, false;
			end
		else
			if curIdx == 1 then -- nextMap是3
				return nextIdx == 1, nextIdx == 2;
			else
				return nextIdx == 2, nextIdx == 3;
			end
		end
	else
		return nextIdx == 1, nextIdx == 2;
	end
end

function Lua_ExpeditionSingleItem:setPathEnable(value, value1, value2)
	if self.checkEff == true and not value and self.baseIcon.isActive and self.baseEff == nil then
		self.value = 1;
		self.baseEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_bjyz_tz", "ui_bjyz_tz_01", 0, -57)
	else
		self.baseIcon:setEnable(value);
	end
	if self.checkEff == true and not value1 and self.path_1.isActive and self.pathEff1 == nil then
		self.value1 = 1;
		self.pathEff1 = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_bjyz_tz", "ui_bjyz_tz_02", -50, 87.5)
		self.pathEff1.siblingIndex = 0
		self.pathEff1:setScale(-1, 1, 1)
	else
		self.path_1:setEnable(value1);
	end
	if self.checkEff == true and not value2 and self.path_2.isActive and self.pathEff2 == nil then
		self.value2 = 1;
		self.pathEff2 = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_bjyz_tz", "ui_bjyz_tz_02", 58, 87.5)
		self.pathEff2.siblingIndex = 0
	else
		self.path_2:setEnable(value2);
	end
	Lua_CommonUtil.delayCall(0.2, self, self.onDelayEnable)
	Lua_CommonUtil.delayCall(1, self, self.removeEff)
end

function Lua_ExpeditionSingleItem:onDelayEnable()
	if self.value == 1 then
		self.baseIcon:setEnable(false)
	end
	if self.value1 == 1 then
		self.path_1:setEnable(false)
	end
	if self.value2 == 1 then
		self.path_2:setEnable(false)
	end
	self.value = nil;
	self.value1 = nil;
	self.value2 = nil;
end

function Lua_ExpeditionSingleItem:showIcon(value)
	if strIsNullOrEmpty(value) then
		self.icon:setEnable(false);
	else
		self.icon:setEnable(true);
		self.icon:setAltas("expedition_atlas_3", value);
		self.icon:resetSize();
		self.icon:setLocation(0, 41, 0);
	end
end

function Lua_ExpeditionSingleItem:showModel(value)
	if strIsNullOrEmpty(value) then
		if self.modelEffImg then
			self.modelEffImg:setEnable(false)
		end
	else
		if self.modelEffImg == nil then
			self.modelEffImg = UICreate.createModelEffImg(self.content, nil, nil, 0, 0, 0, 0)
			self.modelEffImg.siblingIndex = self.icon.siblingIndex
			self.modelEffImg:setCamField(1, 1, 100, true)
			self.modelEffImg.canRot = false
		end
		self.modelEffImg:setEnable(true)
		self.modelEffImg:setUrl("/model/monster/"..value, value)
		self.modelEffImg:setCamRot(25.5, 0 ,0)
		if value == "701020001_low" then
			self.modelEffImg:setCamPos(-0.45, 5, -9)
			self.modelEffImg:setLocation(-36.5, 56.5, 0)
		else
			self.modelEffImg:setCamPos(0, 5, -9)
			self.modelEffImg:setLocation(0, 45, 0)
		end
		self.modelEffImg:setScale(0.25, 0.25, 1)
		self.modelEffImg:setModelEffDir(180)
	end
end

function Lua_ExpeditionSingleItem:showArrow(value)
	if value then
		if self.arrowEff == nil then
			self.arrowEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_bjyz_jt_0001", "ui_bjyz_jt_0001", 0, 160)
		end
		self.arrowEff:setEnable(true)
	else
		if self.arrowEff then
			self.arrowEff:setEnable(false)
		end
	end
end

function Lua_ExpeditionSingleItem:showStar(num)
	if self.starArr == nil then
		self.starArr = Array();
	end
	local len = self.starArr:getSize();
	num = num == nil and 0 or num;
	local maxLen = num > len and num or len;
	local star;
	local w = num * 30;
    w = - w / 2 + 30 / 2;
    local posX;
	for i = 1, maxLen do
		star = self.starArr[i];
		if i > num then
			if star ~= nil then
				star:setEnable(false);
			end
		else
			if star == nil then
				star = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0);
				self.starArr:add(star);
			else
				star:setEnable(true);
			end
			posX = ((i - 1) % num) * 30 + w;
			star:setLocation(posX, 0, 0);
			star:setAltas("common_altas_1", "ui_common_label_11");
		end
	end
end

function Lua_ExpeditionSingleItem:removeEff()
	if self.baseEff then
		self.baseEff:dispose();
		self.baseEff = nil;
	end
	if self.pathEff1 then
		self.pathEff1:dispose();
		self.pathEff1 = nil;
	end
	if self.pathEff2 then
		self.pathEff2:dispose();
		self.pathEff2 = nil;
	end
end

function Lua_ExpeditionSingleItem:showBoxEff(name)
	if strIsNullOrEmpty(name) then
		if self.boxEff then
			self.boxEff:setEnable(false)
		end
		if self.boxEff2 then
			self.boxEff2:setEnable(false)
		end
	else
		if self.boxEff == nil then
			self.boxEff = UICreate.createUIEffect(self.content, nil, nil, 0, 15)
			self.boxEff:setScale(1.5, 1.5, 1.5)
			self.boxEff:addLuaLoadCompleteFun(self, self.onBoxEffLoaded)
		end
		self.boxEff:setEnable(true)
		if self.boxEffName == name then
			self:onBoxEffLoaded()
		else
			self.boxEff:setUrl("/effects/uiEffects/"..name, name)
		end
		self.boxEffName = name
	end
end

function Lua_ExpeditionSingleItem:onBoxEffLoaded()
	self.icon:setEnable(false)
	if self.boxEff2 == nil then
		self.boxEff2 = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_ty_dbx_0102", "ui_ty_dbx_0102", 0, 15)
		self.boxEff2:setScale(1.5, 1.5, 1.5)
	end
	self.boxEff2:setEnable(true)
end

function Lua_ExpeditionSingleItem:onPressClick()
	local data = DataCenter.expeditionData;
	local sub_times = DataCenter.expeditionUtil:getConstConfig("sub_times", 1, 0) * 60;
	if self.data == nil or self.index == nil or self.eventData == nil or (data.left_sec - sub_times) <= 0 then
		OperateAlert.showLangValue(330036);
		return;
	end

	if not self.canClick then
		return;
	end

	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();

	-- 选择BUFF
	if self.data.stage == data.cur_stage and self.data.need_buff == 1 and data.buff_state == 1 then
		Lua_WindowUtil.openWin("Lua_ExpeditionBuffChooseWindow", Lua_WinParam.ACTION_OPEN);
		return;
	end

	if self.eventData.type == 6 then
		-- 选择难度
		local level = DataCenter.expeditionUtil:getConstConfig("difficult_param", 1, 0);
		local force = DataCenter.expeditionUtil:getConstConfig("difficult_force", 1, 0);
		if self.data.difficulty ~= nil and (data.role_level >= level or data.force >= force) then
			Lua_WindowUtil.openWin("Lua_ExpeditionDifficultyWindow", Lua_WinParam.ACTION_OPEN, { stageId = self.data.id, index = self.index });
		else
			Lua_MsgUtil.callFunc("EXPEDITION_GOTO_NEXT", self.data);
		end
		return;
	end

	if self.eventData.operate == 1 then
		Lua_WindowUtil.openWin(self.eventData.param, Lua_WinParam.ACTION_OPEN, { canOperate = self.canOperate, stageId = self.data.id, index = self.index });
	elseif self.eventData.operate == 2 then
		if self.canOperate then
			Lua_MsgUtil.callFunc(self.eventData.param, self.data);
		else
			if self.eventData.type == 7 then
				Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sCheckBox();
			end
		end
	end
end