-- 边境宝藏
Lua_ExpeditionTreasureWindow = class("Lua_ExpeditionTreasureWindow", Lua_Window)
function Lua_ExpeditionTreasureWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ExpeditionTreasureWindow";
	self.skinName = "ExpeditionTreasureWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ExpeditionTreasureWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.bModelShow = false;

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(-250, -157, 0);
	self.itemIcon:setClick(self, self.onCheckArtifact);

	self.btnChange:addClickFuntion(self, self.onChangeModel);
	self.btnBuy:addClickFuntion(self, self.onBuy);

	self:updateShowInfo();
end

function Lua_ExpeditionTreasureWindow:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.modelEffImg then
		self.modelEffImg:dispose();
		self.modelEffImg = nil;
	end
	if self.rewardList then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionTreasureWindow:updateShowInfo()
	local id = DataCenter.expeditionUtil.treasureArtifact;
	self.data = DataCenter.artifactUtil:getArtifactVoById(id);
	self.itemIcon:setData(self.data);
	self.itemIcon:show_level(0);
	self.itemIcon:showStar(1);

	self:updateModel();
	self:updateReward();

	self.priceText.text = LanUtil.formateStr(330044, tostring(DataCenter.expeditionUtil.treasurePrice));
	self.priceText:resetSize();
	local width = self.priceText.width;
	self.line:setLocation(width / 2 + 10, -307, 0);
	self.line:SetDimensions(self.priceText.width - 80, 2);

	id = DataCenter.expeditionUtil.treasureRechargeId;
	local config = Lua_RechargeConfigData.getRechargeConfig(id);
	self.btnBuy.label = LanUtil.formateStr(10062, tostring(config.money));
	self.btnBuy:setMouseEnable(true);
end

function Lua_ExpeditionTreasureWindow:updateModel()
	if self.bModelShow then
		self.bearImg:setEnable(false);
		if self.modelEffImg == nil then
			self.modelEffImg = UICreate.createModelEffImg(self.content, self.data.modelUrl, self.data.modelSrc, false, 18, 180, 0, 0);
			self.modelEffImg.siblingIndex = 1;
		else
			self.modelEffImg:setEnable(true);
			self.modelEffImg:setUrl(self.data.modelUrl, self.data.modelSrc);
		end
		self.btnChange:setAltas("expedition_atlas_3", "xui_bjbz_button_2");
	else
		if self.modelEffImg then
			self.modelEffImg:setEnable(false);
		end
		self.bearImg:setEnable(true);
		self.bearImg:setUrl(self.data.reasurePic);
		self.btnChange:setAltas("expedition_atlas_3", "xui_bjbz_button_1");
	end
end

function Lua_ExpeditionTreasureWindow:updateReward()
	if self.rewardList == nil then
		self.rewardList = Lua_DragList.new(self.content, 402, 124, Lua_AxisDefine.Horizontal);
		self.rewardList:setLocation(105, -157, 0);
		self.rewardList:setListCell(Lua_ItemIconCell, 124, 124, 1);
		self.rewardList:setCellSpacing(15, 0);
		local list = DataCenter.expeditionUtil.treasureReward;
		local arr = Array();
		local vo;
		for i = 1, #list do
			if list[i][1] ~= self.data.unlock_cond[1][1] then
				vo = Lua_ToolVo.createToolVo(list[i][1], list[i][2]);
				arr:add(vo);
			end
		end
		self.rewardList:setArrayData(arr);
	end
end

function Lua_ExpeditionTreasureWindow:onCheckArtifact(go)
	Lua_WindowUtil.openWin("Lua_ArtifactDetailsWindow", Lua_WinParam.ACTION_OPEN, self.data.id);
end

function Lua_ExpeditionTreasureWindow:onChangeModel(go)
	self.bModelShow = not self.bModelShow;
	self:updateModel();
end

function Lua_ExpeditionTreasureWindow:onBuy(go)
	if self.clickTime and getTime() - self.clickTime < 0.3 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();

	local id = DataCenter.expeditionUtil.treasureRechargeId;
	local config = Lua_RechargeConfigData.getRechargeConfig(id);
	DataCenter.sdkInterface:PointOut(tonumber(config.gold), tonumber(config.money), tonumber(config.money_type), tonumber(id), config.gift_name, config.gold);
end