-- 打折商店
Lua_ExpeditionDiscountStoreWindow = class("Lua_ExpeditionDiscountStoreWindow", Lua_Window);
function Lua_ExpeditionDiscountStoreWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ExpeditionDiscountStoreWindow";
	self.skinName = "ExpeditionDiscountStoreWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ExpeditionDiscountStoreWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.haveBuy = false;

	self:addLuaEvent("UPDATE_EXPEDITION_INFO", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_EXPEDITION_INFO_TEMP", self, self.updateShowInfo);
	self:addLuaEvent("EXPEDITION_STORE_LIST", self, self.updateServerInfo);
	self:addLuaEvent("EXPEDITION_DISCOUNTSTORE_SELECT", self, self.onStoreSelected);

	self.itemList = Lua_DragList.new(self.content, 620, 250, Lua_AxisDefine.Horizontal);
	self.itemList:setLocation(0, -137, 0);
	self.itemList.canDrag = false;
	self.itemList:setListCell(Lua_ExpeditionDiscountStoreItem, 150, 200, 1);

	self.des:setLangValue(330025);
	self.btnFunc:addClickFuntion(self, self.onBtnFuncClick);

	self:updateShowInfo();
end

function Lua_ExpeditionDiscountStoreWindow:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self.shopList = nil;
	self.data = nil;
	self:superCall("dispose");
	if DataCenter.expeditionData.isWait == true then
		DataCenter.expeditionData:checkInfoUpdate();
	end
end

function Lua_ExpeditionDiscountStoreWindow:showWin(param)
	self:superCall("showWin", param);

	self.itemList.customParam = param.canOperate;
	self.btnFunc:setEnable(param.canOperate == true);
	Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sStoreList(param.stageId, param.index);
end

function Lua_ExpeditionDiscountStoreWindow:updateShowInfo()
	if DataCenter.expeditionData.cur_state == 1 then
		self.btnFunc:setStyle(3);
		self.btnFunc.txt.colorStr = Lua_ColorDefine.transColorStr("7A6A5F");
		self.btnFunc:setLangValue(330026);
	else
		self.btnFunc:setStyle(1);
		self.btnFunc.txt.colorStr = Lua_ColorDefine.transColorStr("8B5E34");
		self.btnFunc:setLangValue(330027);
	end

	if self.shopList ~= nil then
		self.itemList:setArrayData(self.shopList);
	end
end

function Lua_ExpeditionDiscountStoreWindow:updateServerInfo(msg)
	if msg == nil then
		return;
	end

	self.shopList = msg.shop_list;
	self.haveBuy = false;
	for i = 1, #self.shopList do
		if self.shopList[i].buyed_times == 0 then
			self.haveBuy = true;
			break;
		end
	end
	self:updateShowInfo();
end

function Lua_ExpeditionDiscountStoreWindow:onStoreSelected(data)
	self.data = data;
	if data == nil then
		return;
	end

	local info = DataCenter.expeditionUtil:getStoreInfo(data.shop_id);
	local tvo = Lua_ToolVo.createToolVo(info.item[1]);
	local haveCount = DataCenter.packData:getItemCountById(tvo.id);
	local tipsData = { des = LanUtil.formateStr(330028, tvo.name, tostring(haveCount)), btnType = 1, owner = self, sureFun = self.onSureBuy };
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ExpeditionDiscountStoreWindow:onSureBuy()
	if self.data == nil or self.showData == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sStoreBuy(self.data.shop_id, self.showData.stageId, self.showData.index, 0, self.data.index);
end

function Lua_ExpeditionDiscountStoreWindow:onBtnFuncClick(go)
	if self.showData == nil then
		return;
	end

	if DataCenter.expeditionData.cur_state == 1 then
		if self.haveBuy then
			local tipsData = { des = LanUtil.getValue(330029), btnType = 1, owner = self, sureFun = self.onSureGiveUp };
			Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
		else
			self:onSureGiveUp();
		end
	else
		DataCenter.expeditionData.isWait = true;
		Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sLatticeChoose(self.showData.stageId, self.showData.index);
	end
end

function Lua_ExpeditionDiscountStoreWindow:onSureGiveUp()
	DataCenter.expeditionData.isWait = false;
	Lua_ProxyManager.getProxy("Lua_ExpeditionProxy"):sStoreBuy(0, self.showData.stageId, self.showData.index, 1, 0);
	self:hide();
end




















Lua_ExpeditionDiscountStoreItem = class("Lua_ExpeditionDiscountStoreItem", Lua_ListCell);
function Lua_ExpeditionDiscountStoreItem:ctor(p)
	self:superCall("ctor", p, "ExpeditionDiscountStoreItem_skin");
end

function Lua_ExpeditionDiscountStoreItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setSiblingIndex(0);

	self.btnBuy:setMouseEnable(false);
	self.btnBuy:addClickFuntion(self, self.onBtnBuyClick);
end

function Lua_ExpeditionDiscountStoreItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.costIconItem ~= nil then
		self.costIconItem:dispose();
		self.costIconItem = nil;
	end
	self.customParam = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionDiscountStoreItem:setCustomParam(customParam)
	self.customParam = customParam;
end

function Lua_ExpeditionDiscountStoreItem:setData(data)
	self.data = data
	local info = DataCenter.expeditionUtil:getStoreInfo(data.shop_id);

	local itemVo = Lua_ToolVo.createToolVo(info.item[1], info.item[2]);
	self.itemIcon:setData(itemVo);

	if info.discount and info.discount > 0 then
		self.discount_bg:setEnable(true);
		self.discount:setEnable(true);
		self.discount.text = LanUtil.formateStr(330039, tostring(info.discount));
	else
		self.discount_bg:setEnable(false);
		self.discount:setEnable(false);
	end

	if data.buyed_times > 0 then
		self.btnBuy:setMouseEnable(false);
		self.btnBuy:setStyle(3);
		self.btnBuy.txt.colorStr = Lua_ColorDefine.transColorStr("7A6A5F");
		self.btnBuy:setLangValue(330030);
		if self.costIconItem ~= nil then
			self.costIconItem:setEnable(false);
		end
	else
		if self.costIconItem == nil then
			self.costIconItem = Lua_ConsumeIconItem.new(self.content);
			self.costIconItem:setLocation(0, -105, 0);
			self.costIconItem:setStyle(Lua_MyUISettings.huakangFontName, 26);
		end
		self.costIconItem:setEnable(true);
		itemVo = Lua_ToolVo.createToolVo(info.cost[1], info.cost[2]);

		if self.customParam ~= false and DataCenter.expeditionData.cur_state == 1 then
			self.btnBuy:setStyle(1);
			self.btnBuy:setMouseEnable(true);
			self.costIconItem:setData(itemVo, nil, Lua_ColorDefine.getColorStr("8B5E34", itemVo.count));
		else
			self.btnBuy:setStyle(3);
			self.btnBuy:setMouseEnable(false);
			self.costIconItem:setData(itemVo, nil, Lua_ColorDefine.getColorStr("7A6A5F", itemVo.count));
		end
		self.btnBuy.label = nil
	end
end

function Lua_ExpeditionDiscountStoreItem:onPressClick()
	DataCenter.packUtil:showItemInfo(self.itemIcon.data);
end

function Lua_ExpeditionDiscountStoreItem:onBtnBuyClick(go)
	if self.data == nil then
		return;
	end

	local info = DataCenter.expeditionUtil:getStoreInfo(self.data.shop_id);
	local costId = DataCenter.packData:checkConsumeEnough(info.cost);
	if costId == nil then
		Lua_MsgUtil.callFunc("EXPEDITION_DISCOUNTSTORE_SELECT", self.data);
	else
		DataCenter.packUtil:openPathWindow(costId);
	end
end